@@ -1,11 +1,14 @@
 import os
 import subprocess
 import sys
-from typing import Optional
+from typing import Any, Optional
 
 import click
+from click import UsageError
 
-from ggshield.core.git_shell import GIT_PATH, check_git_dir, check_git_installed
+from ggshield.cmd.common_options import add_common_options
+from ggshield.core.errors import UnexpectedError
+from ggshield.core.git_shell import check_git_dir, git
 
 
 @click.command(context_settings={"ignore_unknown_options": True})
@@ -25,7 +28,10 @@ from ggshield.core.git_shell import GIT_PATH, check_git_dir, check_git_installed
 )
 @click.option("--force", "-f", is_flag=True, help="Force override")
 @click.option("--append", "-a", is_flag=True, help="Append to existing script")
-def install_cmd(mode: str, hook_type: str, force: bool, append: bool) -> int:
+@add_common_options()
+def install_cmd(
+    mode: str, hook_type: str, force: bool, append: bool, **kwargs: Any
+) -> int:
     """Install a pre-commit or pre-push git hook (local or global)."""
     return_code = (
         install_global(hook_type=hook_type, force=force, append=append)
@@ -37,14 +43,11 @@ def install_cmd(mode: str, hook_type: str, force: bool, append: bool) -> int:
 
 def install_global(hook_type: str, force: bool, append: bool) -> int:
     """Global pre-commit/pre-push hook installation."""
-    check_git_installed()
     hook_dir_path = get_global_hook_dir_path()
 
     if not hook_dir_path:
         hook_dir_path = os.path.expanduser("~/.git/hooks")
-        subprocess.run(
-            [GIT_PATH, "config", "--global", "core.hooksPath", hook_dir_path]
-        )
+        git(["config", "--global", "core.hooksPath", hook_dir_path])
 
     return create_hook(
         hook_dir_path=hook_dir_path,
@@ -57,16 +60,11 @@ def install_global(hook_type: str, force: bool, append: bool) -> int:
 
 def get_global_hook_dir_path() -> Optional[str]:
     """Return the default hooks path (if it exists)."""
-    with subprocess.Popen(
-        [GIT_PATH, "config", "--global", "--get", "core.hooksPath"],
-        stdout=subprocess.PIPE,
-    ) as process:
-        if process.returncode:
-            return None
-
-        return os.path.expanduser(
-            click.format_filename(process.communicate()[0].decode("utf-8")).strip()
-        )
+    try:
+        out = git(["config", "--global", "--get", "core.hooksPath"])
+    except subprocess.CalledProcessError:
+        return None
+    return os.path.expanduser(click.format_filename(out))
 
 
 def install_local(hook_type: str, force: bool, append: bool) -> int:
@@ -93,10 +91,10 @@ def create_hook(
     hook_path = f"{hook_dir_path}/{hook_type}"
 
     if os.path.isdir(hook_path):
-        raise click.ClickException(f"{hook_path} is a directory.")
+        raise UsageError(f"{hook_path} is a directory.")
 
     if os.path.isfile(hook_path) and not (force or append):
-        raise click.ClickException(
+        raise UnexpectedError(
             f"{hook_path} already exists."
             " Use --force to override or --append to add to current script"
         )
