@@ -1,14 +1,17 @@
 from functools import partial
-from typing import List
+from typing import Any, List
 
 import click
 
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
+)
 from ggshield.core.constants import MAX_WORKERS
+from ggshield.core.errors import handle_exception
 from ggshield.core.file_utils import get_files_from_paths
 from ggshield.core.text_utils import create_progress_bar
-from ggshield.core.utils import ScanContext, ScanMode, handle_exception
-from ggshield.output import OutputHandler
-from ggshield.scan import ScanCollection
+from ggshield.scan import ScanCollection, ScanContext, ScanMode, SecretScanner
 
 
 @click.command()
@@ -17,15 +20,20 @@ from ggshield.scan import ScanCollection
 )
 @click.option("--recursive", "-r", is_flag=True, help="Scan directory recursively")
 @click.option("--yes", "-y", is_flag=True, help="Confirm recursive scan")
+@add_secret_scan_common_options()
 @click.pass_context
 def path_cmd(
-    ctx: click.Context, paths: List[str], recursive: bool, yes: bool
+    ctx: click.Context,
+    paths: List[str],
+    recursive: bool,
+    yes: bool,
+    **kwargs: Any,
 ) -> int:  # pragma: no cover
     """
     scan files and directories.
     """
     config = ctx.obj["config"]
-    output_handler: OutputHandler = ctx.obj["output_handler"]
+    output_handler = create_output_handler(ctx)
     try:
         files = get_files_from_paths(
             paths=paths,
@@ -47,14 +55,18 @@ def path_cmd(
                 command_path=ctx.command_path,
             )
 
-            results = files.scan(
+            scanner = SecretScanner(
                 client=ctx.obj["client"],
                 cache=ctx.obj["cache"],
-                matches_ignore=config.secret.ignored_matches,
+                ignored_matches=config.secret.ignored_matches,
                 scan_context=scan_context,
                 ignored_detectors=config.secret.ignored_detectors,
-                scan_threads=MAX_WORKERS,
+                ignore_known_secrets=config.ignore_known_secrets,
+            )
+            results = scanner.scan(
+                files.files,
                 progress_callback=partial(progress.update, task_scan),
+                scan_threads=MAX_WORKERS,
             )
         scan = ScanCollection(id=" ".join(paths), type="path_scan", results=results)
 
