@@ -3,24 +3,33 @@ import os
 import sys
 import threading
 from types import TracebackType
-from typing import List, Optional, Tuple, Type
+from typing import Any, List, Optional, Tuple, Type
 
 import click
 
+from ggshield.cmd.secret.scan.secret_scan_common_options import (
+    add_secret_scan_common_options,
+    create_output_handler,
+)
 from ggshield.core.cache import ReadOnlyCache
+from ggshield.core.errors import UnexpectedError, handle_exception
 from ggshield.core.git_shell import get_list_commit_SHA, git
 from ggshield.core.text_utils import display_error
-from ggshield.core.utils import (
-    EMPTY_SHA,
-    PRERECEIVE_TIMEOUT,
-    ScanContext,
-    ScanMode,
-    handle_exception,
-)
+from ggshield.core.utils import EMPTY_SHA, PRERECEIVE_TIMEOUT
 from ggshield.output import GitLabWebUIOutputHandler
+from ggshield.output.text.message import remediation_message
+from ggshield.scan import ScanContext, ScanMode
 from ggshield.scan.repo import scan_commit_range
 
 
+REMEDIATION_MESSAGE = """  A pre-receive hook set server side prevented you from pushing secrets.
+  Since the secret was detected during the push BUT after the commit, you need to:
+  1. rewrite the git history making sure to replace the secret with its reference (e.g. environment variable).
+  2. push again."""
+
+BYPASS_MESSAGE = """\n     git push -o breakglass"""
+
+
 def quit_function() -> None:
     display_error("\nPre-receive hook took too long")
     thread.interrupt_main()  # raises KeyboardInterrupt
@@ -72,16 +81,20 @@ def get_breakglass_option() -> bool:
     return False
 
 
-def find_branch_start(commit: str) -> str:
+def find_branch_start(commit: str) -> Optional[str]:
     """
-    Returns the first local-only commit of the branch
+    Returns the first local-only commit of the branch.
+    Returns None if the branch does not contain any new commit.
     """
     # List all ancestors of `commit` which are not in any branches
     output = git(
         ["rev-list", commit, "--topo-order", "--reverse", "--not", "--branches"]
     )
     ancestors = output.splitlines()
-    return ancestors[0]
+
+    if ancestors:
+        return ancestors[0]
+    return None
 
 
 def parse_stdin() -> Tuple[str, str]:
@@ -90,7 +103,7 @@ def parse_stdin() -> Tuple[str, str]:
     """
     prereceive_input = sys.stdin.read().strip()
     if not prereceive_input:
-        raise click.ClickException(f"Invalid input arguments: '{prereceive_input}'")
+        raise UnexpectedError(f"Invalid input arguments: '{prereceive_input}'")
 
     # TODO There can be more than one line here, for example when pushing multiple
     # branches. We should support this.
@@ -100,7 +113,11 @@ def parse_stdin() -> Tuple[str, str]:
     if old_commit == EMPTY_SHA:
         # Pushing to a new branch
         start_commit = find_branch_start(new_commit)
-        old_commit = f"{start_commit}~1"
+        if start_commit is None:
+            # branch does not contain any new commit
+            old_commit = new_commit
+        else:
+            old_commit = f"{start_commit}~1"
 
     return (old_commit, new_commit)
 
@@ -114,13 +131,16 @@ def parse_stdin() -> Tuple[str, str]:
     help="Deprecated",
     hidden=True,
 )
+@add_secret_scan_common_options()
 @click.pass_context
-def prereceive_cmd(ctx: click.Context, web: bool, prereceive_args: List[str]) -> int:
+def prereceive_cmd(
+    ctx: click.Context, web: bool, prereceive_args: List[str], **kwargs: Any
+) -> int:
     """
     scan as a pre-receive git hook.
     """
     config = ctx.obj["config"]
-    output_handler = ctx.obj["output_handler"]
+    output_handler = create_output_handler(ctx)
 
     if os.getenv("GL_PROTOCOL") == "web":
         # We are inside GitLab web UI
@@ -136,6 +156,12 @@ def prereceive_cmd(ctx: click.Context, web: bool, prereceive_args: List[str]) ->
         return 0
 
     before, after = parse_stdin()
+    if before == after:
+        click.echo(
+            "Pushed branch does not contain any new commit.",
+            err=True,
+        )
+        return 0
 
     if after == EMPTY_SHA:
         click.echo("Deletion event or nothing to scan.", err=True)
@@ -183,18 +209,15 @@ def prereceive_cmd(ctx: click.Context, web: bool, prereceive_args: List[str]) ->
                 matches_ignore=config.secret.ignored_matches,
                 scan_context=scan_context,
                 ignored_detectors=config.secret.ignored_detectors,
+                ignore_known_secrets=config.ignore_known_secrets,
             )
             if return_code:
                 click.echo(
-                    """Rewrite your git history to delete evidence of your secrets.
-Use environment variables to use your secrets instead and store them in a file not tracked by git.
-
-If you don't want to go through this painful git history rewrite in the future,
-you can set up ggshield in your pre commit:
-https://docs.gitguardian.com/internal-repositories-monitoring/integrations/git_hooks/pre_commit
-
-Use it carefully: if those secrets are false positives and you still want your push to pass, run:
-'git push -o breakglass'""",
+                    remediation_message(
+                        remediation_steps=REMEDIATION_MESSAGE,
+                        bypass_message=BYPASS_MESSAGE,
+                        rewrite_git_history=True,
+                    ),
                     err=True,
                 )
             return return_code
