@@ -26,12 +26,20 @@ STYLE: Dict[str, Dict[str, Any]] = {
     "no_secret": {"fg": "white"},
     "detector": {"fg": "bright_yellow", "bold": True},
     "policy": {"fg": "cyan", "bold": True},
-    "ignore_sha": {"fg": "cyan"},
     "detector_line_start": {"fg": "cyan"},
     "line_count": {"fg": "white", "dim": True},
     "line_count_secret": {"fg": "yellow"},
     "progress": {"fg": "bright_yellow", "bold": False},
     "warning": {"fg": "yellow"},
+    "incident_validity": {"fg": "bright_yellow", "bold": True},
+    "policy_break_type": {"fg": "bright_yellow", "bold": True},
+    "occurrence_count": {"fg": "bright_yellow", "bold": True},
+    "ignore_sha": {"fg": "bright_yellow", "bold": True},
+    "iac_vulnerability_critical": {"fg": (255, 0, 0), "bold": True},  # red
+    "iac_vulnerability_high": {"fg": (255, 128, 0), "bold": True},  # orange
+    "iac_vulnerability_medium": {"fg": "bright_yellow", "bold": True},
+    "iac_vulnerability_low": {"fg": (146, 146, 146), "bold": True},  # light-grey
+    "iac_vulnerability_unknown": {"fg": "bright_yellow", "bold": True},
 }
 
 
