@@ -5,7 +5,6 @@ from typing import Any, Dict, Optional
 from unittest.mock import Mock
 
 import pytest
-from click import ClickException
 
 from ggshield.cmd.auth.utils import (
     DISABLED_FLOW_MESSAGE,
@@ -14,6 +13,7 @@ from ggshield.cmd.auth.utils import (
 )
 from ggshield.cmd.main import cli
 from ggshield.core.config import Config
+from ggshield.core.errors import ExitCode, UnexpectedError
 from ggshield.core.oauth import (
     OAuthClient,
     OAuthError,
@@ -50,7 +50,7 @@ DT_FORMAT = "%Y-%m-%dT%H:%M:%S%z"
 @pytest.fixture(autouse=True)
 def tmp_config(monkeypatch, tmp_path):
     monkeypatch.setattr(
-        "ggshield.core.config.utils.get_auth_config_dir", lambda: str(tmp_path)
+        "ggshield.core.config.utils.get_config_dir", lambda: str(tmp_path)
     )
 
 
@@ -195,6 +195,38 @@ class TestAuthLoginToken:
             == second_instance_token
         )
 
+    def test_auth_login_token_from_stdin(self, monkeypatch, cli_fs_runner):
+        """
+        GIVEN a valid API token in stdin input
+        WHEN the auth login command is called
+        THEN the authentication is successfully made
+        """
+        config = Config()
+        assert len(config.auth_config.instances) == 0
+
+        self.mock_autho_login_request(monkeypatch, 200, self.VALID_TOKEN_PAYLOAD)
+
+        token = "mysupertoken"
+
+        get_text_stream_mock = Mock()
+        get_text_stream_mock.isatty.return_value = False
+        get_text_stream_mock.read.return_value = token
+        monkeypatch.setattr(
+            "ggshield.cmd.auth.click.get_text_stream",
+            Mock(return_value=get_text_stream_mock),
+        )
+
+        cmd = ["auth", "login", "--method=token"]
+
+        result = cli_fs_runner.invoke(cli, cmd, color=False)
+
+        config = Config()
+        assert_invoke_ok(result)
+
+        assert (
+            config.auth_config.get_instance(config.instance_name).account.token == token
+        )
+
 
 class TestAuthLoginWeb:
     @pytest.mark.parametrize("instance_url", [None, "https://some_instance.com"])
@@ -204,7 +236,7 @@ class TestAuthLoginWeb:
         prepare_config(instance_url=instance_url)
 
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 0, output
+        assert exit_code == ExitCode.SUCCESS, output
         self._webbrowser_open_mock.assert_not_called()
 
         self._assert_last_print(
@@ -231,7 +263,7 @@ class TestAuthLoginWeb:
         prepare_config(instance_url=instance_url, expiry_date=dt)
 
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 0, output
+        assert exit_code == ExitCode.SUCCESS, output
         self._webbrowser_open_mock.assert_not_called()
 
         self._assert_last_print(
@@ -248,7 +280,7 @@ class TestAuthLoginWeb:
 
         self.prepare_mocks(monkeypatch, used_port_count=1000)
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 1
+        assert exit_code == ExitCode.UNEXPECTED_ERROR
 
         self._webbrowser_open_mock.assert_not_called()
         self._client_post_mock.assert_not_called()
@@ -279,7 +311,7 @@ class TestAuthLoginWeb:
             is_state_valid=is_state_valid,
         )
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 1
+        assert exit_code == ExitCode.UNEXPECTED_ERROR
 
         self._webbrowser_open_mock.assert_called_once()
         self._assert_open_url()
@@ -301,7 +333,7 @@ class TestAuthLoginWeb:
         """
         self.prepare_mocks(monkeypatch, is_exchange_ok=False)
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 1
+        assert exit_code == ExitCode.UNEXPECTED_ERROR
 
         self._webbrowser_open_mock.assert_called_once()
         self._assert_open_url()
@@ -319,7 +351,7 @@ class TestAuthLoginWeb:
         """
         self.prepare_mocks(monkeypatch, is_token_valid=False)
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 1
+        assert exit_code == ExitCode.UNEXPECTED_ERROR
 
         self._webbrowser_open_mock.assert_called_once()
         self._assert_open_url()
@@ -362,7 +394,7 @@ class TestAuthLoginWeb:
             prepare_config(instance_url="http://some-gg-instance.com")
 
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 0, output
+        assert exit_code == ExitCode.SUCCESS, output
 
         self._webbrowser_open_mock.assert_called_once()
         self._assert_open_url(expected_port=29170 + used_port_count)
@@ -459,7 +491,9 @@ class TestAuthLoginWeb:
         if is_exchange_ok:
             token_response_payload = _TOKEN_RESPONSE_PAYLOAD.copy()
             if lifetime is not None:
-                token_response_payload["expire_at"] = self._get_expiry_date()
+                token_response_payload[
+                    "expire_at"
+                ] = self._get_expiry_date().isoformat()
 
         # mock api call to exchange the code against a valid access token
         self._client_post_mock = Mock(
@@ -640,7 +674,7 @@ class TestAuthLoginWeb:
                 try:
                     self.process_callback(callback_url)
                 except OAuthError as e:
-                    raise ClickException(e.message)
+                    raise UnexpectedError(e.message)
 
         return FakeOAuthClient
 
@@ -693,7 +727,7 @@ class TestAuthLoginWeb:
         monkeypatch.setattr("ggshield.core.client.Session.get", client_get_mock)
 
         if expected_error:
-            with pytest.raises(ClickException, match=expected_error):
+            with pytest.raises(UnexpectedError, match=expected_error):
                 check_instance_has_enabled_flow(Config())
         else:
             check_instance_has_enabled_flow(Config())
@@ -787,7 +821,7 @@ class TestAuthLoginWeb:
         self._check_instance_has_enabled_flow_mock.side_effect = setter
 
         exit_code, output = self.run_cmd(cli_fs_runner)
-        assert exit_code == 0, output
+        assert exit_code == ExitCode.SUCCESS, output
         self._webbrowser_open_mock.assert_called()
         self._assert_open_url(host=expected_web_host)
         self._check_instance_has_enabled_flow_mock.assert_called_once()
