@@ -1,4 +1,5 @@
 from ggshield.cmd.main import cli
+from ggshield.core.errors import ExitCode
 from tests.unit.conftest import assert_invoke_exited_with
 
 
@@ -12,7 +13,7 @@ class TestScanRepo:
         result = cli_fs_runner.invoke(
             cli, ["scan", "repo", "https://github.com/gitguardian/ggshield"]
         )
-        assert_invoke_exited_with(result, 1)
+        assert_invoke_exited_with(result, ExitCode.USAGE_ERROR)
         assert (
             "Error: https://github.com/gitguardian/ggshield doesn't seem to "
             "be a valid git URL.\nDid you mean "
@@ -28,7 +29,7 @@ class TestScanRepo:
         result = cli_fs_runner.invoke(
             cli, ["scan", "repo", "trial.gitguardian.com/gitguardian/ggshield"]
         )
-        assert_invoke_exited_with(result, 1)
+        assert_invoke_exited_with(result, ExitCode.USAGE_ERROR)
         assert (
             "Error: trial.gitguardian.com/gitguardian/ggshield is"
             " neither a valid path nor a git URL" in result.output
